/*********************************************************************************
 *  Display_Numerical.c
 *  -------------------
 *
 *  Description
 *  Display Numbers
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/

#include <avr/io.h> 
#include <util/delay.h> 


#include "Display_SPI.h"
#include "Display_Numerical.h"




/*********************************************************************************
 *  DisplayDecimal8
 *********************************************************************************
 *  Description: Displays 8bit number in decimal format (3 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(1Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayDecimal8(uint16_t x, uint16_t y, uint8_t value)
{

  if (!SendCommand(CMD_DisplayDecimal8)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW(value);

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayDecimal16
 *********************************************************************************
 *  Description: Displays 16bit number in decimal format (5 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(2Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayDecimal16(uint16_t x, uint16_t y, uint16_t value)
{

  if (!SendCommand(CMD_DisplayDecimal16)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>8)); // MSB value
  SPI_RW((uint8_t)value);      // LSB value

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayDecimal32
 *********************************************************************************
 *  Description: Displays 32bit number in decimal format (10 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(4Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayDecimal32(uint16_t x, uint16_t y, uint32_t value)
{

  if (!SendCommand(CMD_DisplayDecimal32)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>24));// MSB value
  SPI_RW((uint8_t)(value>>16));
  SPI_RW((uint8_t)(value>>8));
  SPI_RW((uint8_t)value);      // LSB value

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayDecimalSigned8
 *********************************************************************************
 *  Description: Displays 8bit number in signed decimal format (4 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(1Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayDecimalSigned8(uint16_t x, uint16_t y, uint8_t value)
{

  if (!SendCommand(CMD_DisplayDecimalSigned8)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW(value);

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayDecimalSigned16
 *********************************************************************************
 *  Description: Displays 16bit number in signed decimal format (6 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(2Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayDecimalSigned16(uint16_t x, uint16_t y, uint16_t value)
{

  if (!SendCommand(CMD_DisplayDecimalSigned16)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>8)); // MSB value
  SPI_RW((uint8_t)value);      // LSB value

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayDecimalSigned32
 *********************************************************************************
 *  Description: Displays 32bit number in signed decimal format (11 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(4Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayDecimalSigned32(uint16_t x, uint16_t y, uint32_t value)
{

  if (!SendCommand(CMD_DisplayDecimalSigned32)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>24));// MSB value
  SPI_RW((uint8_t)(value>>16));
  SPI_RW((uint8_t)(value>>8));
  SPI_RW((uint8_t)value);      // LSB value

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}


/*********************************************************************************
 *  DisplayHex8
 *********************************************************************************
 *  Description: Displays 8bit number in hexadecimal format (2 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(1Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayHex8(uint16_t x, uint16_t y, uint8_t value)
{

  if (!SendCommand(CMD_DisplayHex8)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW(value);

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayHex16
 *********************************************************************************
 *  Description: Displays 16bit number in hexadecimal format (4 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(2Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayHex16(uint16_t x, uint16_t y, uint16_t value)
{

  if (!SendCommand(CMD_DisplayHex16)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>8)); // MSB
  SPI_RW((uint8_t)value);      // LSB

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayHex32
 *********************************************************************************
 *  Description: Displays 32bit number in hexadecimal format (8 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(4Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayHex32(uint16_t x, uint16_t y, uint32_t value)
{

  if (!SendCommand(CMD_DisplayHex32)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>24));// MSB value
  SPI_RW((uint8_t)(value>>16));
  SPI_RW((uint8_t)(value>>8));
  SPI_RW((uint8_t)value);      // LSB value

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayHex64
 *********************************************************************************
 *  Description: Displays 64bit number in hexadecimal format (16 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(8Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayHex64(uint16_t x, uint16_t y, uint64_t value)
{

  if (!SendCommand(CMD_DisplayHex64)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y

  SPI_RW((uint8_t)(value>>56));// MSB value
  SPI_RW((uint8_t)(value>>48));
  SPI_RW((uint8_t)(value>>40));
  SPI_RW((uint8_t)(value>>32));
  SPI_RW((uint8_t)(value>>24));
  SPI_RW((uint8_t)(value>>16));
  SPI_RW((uint8_t)(value>>8));
  SPI_RW((uint8_t)value);      // LSB value

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DisplayBinary8
 *********************************************************************************
 *  Description: Displays 8bit number in binary format (8 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(1Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayBinary8(uint16_t x, uint16_t y, uint8_t value)
{

  if (!SendCommand(CMD_DisplayBinary8)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW(value);

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}


/*********************************************************************************
 *  DisplayBinary16
 *********************************************************************************
 *  Description: Displays 8bit number in binary format (16 digits)
 *
 *  Input Arguments:
 *    x		: location x	(2Byte)
 *    y		: location y	(2Byte)
 *    value : number to display	(2Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayBinary16(uint16_t x, uint16_t y, uint16_t value)
{

  if (!SendCommand(CMD_DisplayBinary16)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y
  SPI_RW((uint8_t)(value>>8)); // MSB
  SPI_RW((uint8_t)value);      // LSB

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}


/*********************************************************************************
 *  NumericalConfig
 *********************************************************************************
 *  Description: Configurate several display modes for numerical instructions
 *
 *  Input Arguments:
 *    config	: configuration	(1Byte)
 *
 *  Bit Position
 *  0 : display no plus             NCONF_NoPlus      (DisplayDecimalSigned)
 *  1 : display no leading zero     NCONF_NoZero      (DisplayDecimal, DisplayDecimalSigned)
 *  2 : display left adjusted       NCONF_LeftAdjust  (DisplayDecimal, DisplayDecimalSigned)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void NumericalConfig(uint8_t config)
{

  if (!SendCommand(CMD_NumericalConfig)) return; // Send command

  SPI_RW(config);    

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}























