/*********************************************************************************
 *  Display_System.c
 *  ------------------
 *
 *  Description
 *  System configuration commands
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/

#include <avr/io.h> 
#include <util/delay.h> 


#include "Display_SPI.h"
#include "Display_System.h"




/*********************************************************************************
 *  SeftwareReset
 *********************************************************************************
 *  Description: Performs a software reset
 *
 *  Input Arguments:
 *    none
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void SoftwareReset(void)
{

  if (!SendCommand(CMD_SoftwareReset)) return; // Send command

  SPI_RW((uint8_t)(CMD_SoftwareReset_A>>8));     // Subcommand MSB
  SPI_RW((uint8_t)CMD_SoftwareReset_A);          // Subcommand LSB

  _delay_us(1);
  SPI_SS_HIGH       // Deselect SPI
  _delay_ms(100);

  WaitWhileDisplayBusy();   // Wait while Display signals BUSY
                  
}


/*********************************************************************************
 *  SetBacklightIntensity
 *********************************************************************************
 *  Description: Set Intensity of Backlight
 *
 *
 *  Input Arguments:
 *    intensity: Intensity of Backlight (1Byte) 0..255
 *               (0=Backlight off, 255=highest Intensity)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 16.03.2011   State: tested | released
 *********************************************************************************/
void SetBacklightIntensity(uint8_t intensity)
{

  if (!SendCommand(CMD_SetBacklightIntensity)) return;

  SPI_RW(intensity);    // Intensity

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  SetDisplayMode
 *********************************************************************************
 *  Description: Set Portrait or Landscape mode
 *
 *
 *  Input Arguments:
 *    mode: Display mode Portrait or Landscape (1Byte)
 *          Portrait=0, Landscape=1
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 18.03.2011   State: tested | released
 *********************************************************************************/
void SetDisplayMode(uint8_t mode)
{

  if (!SendCommand(CMD_SetDisplayMode)) return;

  SPI_RW(mode);    // Displaymode

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

/*********************************************************************************
 *  DebugMode
 *********************************************************************************
 *  Description: Set debug mode on or off
 *
 *
 *  Input Arguments:
 *    mode: 0 = debug mode off
 *          1 = debug mode on
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 18.03.2011   State: tested | released
 *********************************************************************************/
void DebugMode(uint8_t mode)
{

  if (!SendCommand(CMD_DebugMode)) return;

  SPI_RW(mode);    // Displaymode

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}

















