/*********************************************************************************
 *  Display_UserMemory.c
 *  --------------------
 *
 *  Description
 *  Display Images and Text from on display module user memory
 *  (Flash and MicroSD Card)
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/

#include <avr/io.h> 
#include <util/delay.h> 


#include "Display_SPI.h"
#include "Display_UserMemory.h"

/*********************************************************************************
 *  DisplayImagePackage_Image
 *********************************************************************************
 *  Description: Displays an Bitmap Image stored on displays onboard 8MB
 *               flash memory
 *
 *  Input Arguments:
 *    x	: 				location x			(2Byte)
 *    y	: 				location y			(2Byte)
 *    package index: 	index of package 	(1Byte) 0..31
 *    item index:		index of image 		(2Byte)
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplayImagePackage_Image(uint16_t x, uint16_t y, uint8_t packageindex, uint16_t itemindex)
{

  if (!SendCommand(CMD_DisplayImagePackage_Image)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y

  SPI_RW(packageindex);        // index of package
  SPI_RW((uint8_t)(itemindex>>8));     // MSB index of image
  SPI_RW((uint8_t)itemindex);          // LSB index of image

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}


/*********************************************************************************
 *  DisplaySDCard_Image
 *********************************************************************************
 *  Description: Displays an Bitmap Image stored on MicroSD Card
 *
 *  Filename: max. length 12 Byte. Example: img0001.bmp
 *  
 *  Note:     If Bitmap Image doesnt match display panel, the image will not
 *            be displayed. 
 *
 *  Input Arguments:
 *    x	: 	location x			(2Byte)
 *    y	: 	location y			(2Byte)
 *    name: pointer to string   (string length: max. 12Byte)
 *                              Example: img001.bmp
 *
 *  Output Variable
 *    none
 *
 *********************************************************************************
 *  Revision: 1   Date: 23.02.2011   State: tested | released
 *********************************************************************************/
void DisplaySDCard_Image(uint16_t x, uint16_t y, unsigned char *filename)
{
  uint8_t i;

  if (!SendCommand(CMD_DisplaySDCard_Image)) return; // Send command

  SPI_RW((uint8_t)(x>>8));     // MSB x
  SPI_RW((uint8_t)x);          // LSB x
  SPI_RW((uint8_t)(y>>8));     // MSB y
  SPI_RW((uint8_t)y);          // LSB y

  i = 0;
  while (filename[i] && (i<12))
  {
    SPI_RW(filename[i]); 
    i++; 
  }
  SPI_RW(0); 

  SPI_SS_HIGH                         // Deselect SPI
  WaitWhileDisplayBusy();             // Wait while Display signals BUSY

}



