/****************************************************************************
 *
 * Demonstration of instruction set
 *
 * ---------------------------------------------------------------------------
 *
 * Display-Module  : XV-TFT2428T
 *                   (This demonstration software uses Touchpanel of display
 *                   module.)
 *
 * Microcontroller : AVR
 * Compiler        : AVR GCC
 *
 * File            : main.c
 *
 * Revision        : 1
 * Datum           : 22.07.2011
 * Autor           : Dirk Rodenhausen
 * Website         : xv-display.de
 *
 * Copyright (c) 2011, Rodenhausen Electronic, All rights reserved.
 *
 * Note:
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following disclaimer
 * specified in the documentation and/or other materials provided with
 * the distribution.
 *
 * DISCLAIMER:
 * THIS SOFTWARE IS PROVIDED BY RODENHAUSEN ELECTRONIC "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL RODENHAUSEN ELECTRONIC BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

 
#include <avr/io.h>      
#include <util/delay.h> 
#include <avr/pgmspace.h>


#include "Display_SPI.h"
#include "Display_Graphics.h"
#include "Display_Numerical.h"
#include "Display_TouchPanel.h"
#include "Display_UserMemory.h"
#include "Display_Text.h"
#include "Display_System.h"


#include "dos.h"			
#include "fat.h"			
#include "dosdefs.h"						
#include "mmc_spi.h"
#include "find_x.h"		






#define nop() __asm volatile ("nop")

// Prototypes
void Demo_System(void);
void Demo_UserMemory(void);
void Demo_TextGlobal(void);
void Demo_Graphics(void);
void Demo_Numerical(void);
void Demo_TouchPanel(void);


// Prototypes of helpers
void CreateFileName(unsigned char *s, uint8_t index);  // Help function
uint8_t Wait_ms(uint16_t ms);


int main (void)
{

MMC_IO_Init();


  SPI_Init();                     // Init DisplayInterface

  _delay_ms(100);

  while (DISPLAY_BUSY) {nop(); }


    SetPenColor(0, 0, 0);        // Pen Color black
    SetBrushColor(255, 255, 255);// Brush Color white
    SetFont(1);                  // Text and Number Font 1

    FillScreen_BrushColor();
    // DebugMode(1);                // DebugMode on
    SetBacklightIntensity(255);  // Backlight brightness 100%

    DisplayText_F(65, 140, PSTR("xv-display.de"));


 if(GetDriveInformation()!=F_OK) // get drive parameters
  {

    // Gib hier eine Fehlermeldung raus
  DisplayText_F(65, 140, PSTR("FEHLER"));


   while(1);
  }


DisplayText_F(65, 140, PSTR("  ok "));



  while (1)
  {

    SetPenColor(0, 0, 0);        // Pen Color black
    SetBrushColor(255, 255, 255);// Brush Color white
    SetFont(1);                  // Text and Number Font 1
    SetBacklightIntensity(255);  // Backlight brightness 100%

    FillScreen_BrushColor();
    DisplayText_F(70, 120, PSTR("xv-display.de"));
    DisplayText_F(65, 140, PSTR("Display Module"));
	SetFont(0);
    DisplayText_F(15, 160, PSTR("Demonstration of Instruction Set"));
    SetFont(1);

    _delay_ms(5000);


    Demo_System();
    Demo_TextGlobal();
    Demo_Graphics();
    Demo_Numerical();
    Demo_TouchPanel();
    Demo_UserMemory();


    DrawRect_BrushColorFill(0, 0, 239, 319);
    DisplayText_F(5, 5, PSTR("Repeating Demonstration ..."));
    _delay_ms(2000);


  }



  return 0;
}






void Demo_System(void)
{

  uint8_t intensity, proceed;

 /**************************************************************
  * System
  **************************************************************/  

  /*
  void SoftwareReset(void);
  void SetBacklightIntensity(uint8_t intensity);
  void SetDisplayMode(uint8_t mode);
  */

  // *****************************************************
  // Header
  // *****************************************************
  FillScreen_BrushColor();
  SetPenColor(255, 255, 255);
  SetBrushColor(80, 80, 200);
  DrawRect_BrushColorFill(2, 2, 237, 16);
  DisplayText_F(5, 5, PSTR("System Instructions"));
  SetPenColor(0, 0, 0);
  SetBrushColor(255, 255, 255);

  _delay_ms(2000);

  TouchPanel_SetConfig(0b00000111);

  proceed = 1;
  do
  {

    // Set Display Mode: Portrait
    SetDisplayMode(DISPLAYMODE_Portrait);
    DisplayText_F(5, 5, PSTR("Display Mode Portrait"));
	if (!Wait_ms(2000)) proceed=0;
	if (proceed)
	{    
	  DisplayImagePackage_Image(0, 0, 0, 0);
	  if (!Wait_ms(2000)) proceed=0;
    }

    // Set Display Mode: Landscape
	if (proceed)
	{
      SetDisplayMode(DISPLAYMODE_Landscape);
	  DisplayText_F(5, 5, PSTR("Display Mode Landscape"));
	  if (!Wait_ms(2000)) proceed=0;
	  if (proceed)
	  {
        DisplayImagePackage_Image(0, 0, 1, 0);		
	    if (!Wait_ms(2000)) proceed=0;
      }
	}


    DisplayText_F(5, 5, PSTR("Backlight Intensity   "));
    if (proceed)
	{
      intensity = 255;
      do
      {
		_delay_ms(15);
	    DisplayDecimal8(140, 5, intensity);
	    SetBacklightIntensity(intensity);
	    intensity--;
	  } while (intensity>0);

      do
	  {
        _delay_ms(15);
	    DisplayDecimal8(140, 5, intensity);
        SetBacklightIntensity(intensity);
        intensity++;
      } while (intensity<255);
    }

  } while (proceed);


  SetBacklightIntensity(255);
  SetDisplayMode(DISPLAYMODE_Portrait);

}


void Demo_UserMemory(void)
{

  uint8_t packageindex, proceed;
  uint16_t itemindex;
  unsigned char filename[12];



 /**************************************************************
  * User Memory
  **************************************************************/  

  /*
  void DisplayImagePackage_Image(uint16_t x, uint16_t y, uint8_t packageindex, uint16_t itemindex);
  void DisplayImagePackage_Text(uint16_t x, uint16_t y, uint8_t packageindex, uint16_t itemindex);
  void DisplaySDCard_Image(uint16_t x, uint16_t y, unsigned char *filename);
  */

  // *****************************************************
  // Header
  // *****************************************************
  FillScreen_BrushColor();
  SetPenColor(255, 255, 255);
  SetBrushColor(80, 80, 200);
  DrawRect_BrushColorFill(2, 2, 237, 16);
  DisplayText_F(5, 5, PSTR("User Memory Instructions"));
  SetPenColor(0, 0, 0);
  SetBrushColor(255, 255, 255);


  SetPenColor(0, 0, 255);
  DisplayText_F(5, 40, PSTR("Touch display panel to start"));
  DisplayText_F(5, 50, PSTR("demonstration ..."));
  SetPenColor(0, 0, 0);


  TouchPanel_SetConfig(0b00000111);  // RadioGroupBox Events enable


  proceed = 1;
  do
  {

    if (TOUCHPANEL_EVENT)
    {
      if (TOUCH_EVENT_DOWN & TouchPanel_ReadEvent()) proceed = 0;
	}

  } while (proceed);


  DisplayText_F(5, 80, PSTR("Display Images from internal"));
  DisplayText_F(5, 90, PSTR("flash memory ..."));
  Wait_ms(2000);


  proceed = 1;
  packageindex = 0;
  itemindex = 0;
  do
  {

    DisplayImagePackage_Image(0, 0, packageindex, itemindex);
    itemindex++;
	if (itemindex > 35) itemindex = 0;
	if (0 == Wait_ms(1000)) proceed = 0;

  } while (proceed);


  DrawRect_BrushColorFill(0, 0, 239, 319);
  DisplayText_F(5, 5, PSTR("User Memory Instructions"));
  DrawLine_RGBColor(5, 17, 234, 17, 20, 20, 50);
  DisplayText_F(5, 80, PSTR("Display Images from micro SDCard"));
  Wait_ms(2000);

  itemindex = 0;
  proceed = 1;
  do
  {

    CreateFileName(filename, itemindex);  // creates filename "nnnnn.bmp" n=decimal itemindex
	DisplayText(5, 300, filename);
	DisplaySDCard_Image(0, 0, filename);
    itemindex++;
	if (itemindex > 60) itemindex = 0;
	if (0 == Wait_ms(1000)) proceed = 0;

  } while (proceed);


}





void Demo_TouchPanel(void)
{

  uint16_t x, y;
  uint8_t data;

  // *****************************************************
  // Header
  // *****************************************************
  FillScreen_BrushColor();
  SetPenColor(255, 255, 255);
  SetBrushColor(80, 80, 200);
  DrawRect_BrushColorFill(2, 2, 237, 16);
  DisplayText_F(5, 5, PSTR("TouchPanel Instructions"));
  SetPenColor(0, 0, 0);
  SetBrushColor(255, 255, 255);

  _delay_ms(2000);

  DisplayText_F(5, 25, PSTR("Press touch panel ..."));

  TouchPanel_SetConfig(0b00000111);

  // Draw Clear and Cancel Button
  DrawRect_RGBColorFill(10, 280, 110, 310, 120, 120, 220);   // Clear
  DrawRect_RGBColorFill(130, 280, 230, 310, 120, 120, 220);  // Cancel
  SetBrushColor(120, 120, 220);
  DisplayText_F(45, 290, PSTR("Clear"));
  DisplayText_F(160, 290, PSTR("Cancel"));
  SetBrushColor(255, 255, 255);

  data = TouchPanel_ReadEvent();  // clear events 


  while (1)
  {


    if (TOUCHPANEL_EVENT)
    {
      data = TouchPanel_ReadEvent();
     
	  if (data & TOUCH_EVENT_DOWN)
	  {
        if (TouchPanel_ReadDown(&x, &y))
		{
          DrawCircle_RGBColor(x, y, 10, 255, 0, 0);
		  MoveTo(x, y);
		}

		if ((y>280) && (y<310))
		{
           if ((x>10) && (x<110))  // Clear
		   {
		   
             DrawRect_BrushColorFill(0, 0, 239, 319);
             DisplayText_F(5, 5, PSTR("TouchPanel Instructions"));
             DrawLine_RGBColor(5, 17, 234, 17, 20, 20, 50);
             DisplayText_F(5, 25, PSTR("Press touch panel ..."));
             DrawRect_RGBColorFill(10, 280, 110, 310, 120, 120, 220);   // Clear
             DrawRect_RGBColorFill(130, 280, 230, 310, 120, 120, 220);  // Cancel
             SetBrushColor(120, 120, 250);
             DisplayText_F(45, 290, PSTR("Clear"));
             DisplayText_F(160, 290, PSTR("Cancel"));
             SetBrushColor(255, 255, 255);
		   		   
		   } else
		   if ((x>120) && (x<230)) return;  // Cancel
		}

	  }

	  if (data & TOUCH_EVENT_UP)
	  {
        if (TouchPanel_ReadUp(&x, &y))
		{
          DrawCircle_RGBColor(x, y, 10, 0, 0, 255);
		}

	  }

	  if (data & TOUCH_EVENT_CONT)
	  {
        if (TouchPanel_ReadCont(&x, &y))
		{
         // DrawPixel_PenColor(x, y);
		  LineTo_PenColor(x, y);
		}

	  }

    }
  }


}


void Demo_TextGlobal(void)
{

  uint8_t r, g, b;
  uint16_t i, j;
  
 /**************************************************************
  * TextGlobal
  **************************************************************/  
  
  
  /*
  void DisplayText(uint16_t x, uint16_t y, unsigned char *s);
  void DisplayText_F(uint16_t x, uint16_t y, char *s);
  void SetFont(uint8_t index);
  void SetTextMarginX(uint16_t x);
  uint16_t GetTextWidth(unsigned char *s);
  void SetPenColor(uint8_t r, uint8_t g, uint8_t b);
  void SetBrushColor(uint8_t r, uint8_t g, uint8_t b);
  */


  TouchPanel_SetConfig(0b00000111); // Enable Touchpanel Events


  // *****************************************************
  // Header
  // *****************************************************
  FillScreen_BrushColor();
  SetPenColor(255, 255, 255);
  SetBrushColor(80, 80, 200);
  DrawRect_BrushColorFill(2, 2, 237, 16);
  DisplayText_F(5, 5, PSTR("Text and global Instructions"));
  SetPenColor(0, 0, 0);
  SetBrushColor(255, 255, 255);


  if (0 == Wait_ms(2000)) return;


  DisplayText_F(5, 35, PSTR("PenColor and BrushColor"));
  DisplayText_F(5, 45, PSTR("Display Text with varied fonts ..."));


  r=0;
  g=0;
  b=0;

    do  // changing red
	{
      SetPenColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Pen Color (R) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_PenColorFill(100, 160, 140, 180);
	  r++;
    } while (r<255);

    do  // changing green
	{
      SetPenColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Pen Color (G) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_PenColorFill(100, 160, 140, 180);
	  g++;
    } while (g<255);

    do  // changing blue
	{
      SetPenColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Pen Color (B) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_PenColorFill(100, 160, 140, 180);
	  b++;
    } while (b<255);


    do  // changing red
	{
	  r--;
      SetPenColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Pen Color (R) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_PenColorFill(100, 160, 140, 180);
    } while (r>0);

    do  // changing green
	{
	  g--;
      SetPenColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Pen Color (G) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_PenColorFill(100, 160, 140, 180);
    } while (g>0);

    do  // changing blue
	{
	  b--;
      SetPenColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Pen Color (B) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);	  
	  DrawRect_PenColorFill(100, 160, 140, 180);
    } while (b>0);



  SetPenColor(30, 30, 30);
  r=0;
  g=0;
  b=0;


    do  // changing red
	{
      SetBrushColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Brush Color (R) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_BrushColorFill(100, 160, 140, 180);
	  r++;
    } while (r<255);

    do  // changing green
	{
      SetBrushColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Brush Color (G) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_BrushColorFill(100, 160, 140, 180);
	  g++;
    } while (g<255);

    do  // changing blue
	{
      SetBrushColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Brush Color (B) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_BrushColorFill(100, 160, 140, 180);
	  b++;
    } while (b<255);


    do  // changing red
	{
	  r--;
      SetBrushColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Brush Color (R) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_BrushColorFill(100, 160, 140, 180);
    } while (r>0);

    do  // changing green
	{
	  g--;
      SetBrushColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Brush Color (G) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_BrushColorFill(100, 160, 140, 180);
    } while (g>0);

    do  // changing blue
	{
	  b--;
      SetBrushColor(r, g, b);
      DisplayText_F(5, 100, PSTR("Changing Brush Color (B) ..."));
	  DisplayText_F(5, 120, PSTR("R ="));
	  DisplayText_F(5, 130, PSTR("G ="));
	  DisplayText_F(5, 140, PSTR("B ="));
	  DisplayDecimal8(40, 120, r);
	  DisplayDecimal8(40, 130, g);
	  DisplayDecimal8(40, 140, b);
	  DrawRect_BrushColorFill(100, 160, 140, 180);
    } while (b>0);




  SetPenColor(0, 0, 0);
  SetBrushColor(255, 255, 255);



   DrawRect_BrushColorFill(0, 35, 239, 319);

   for (i=0; i<17; i++)
   {

     SetFont(i);
	 j = 25+(i*16); 
	 DisplayText_F(5, j, PSTR("Font Index"));
     DisplayDecimal8(180, j, i);

   }
   _delay_ms(5000);

  SetFont(1);


}

void Demo_Numerical(void)
{

  uint8_t data, config;
  uint8_t i8;
  uint16_t i16, i;
  uint32_t i32;
  int8_t j8;
  int16_t j16;
  int32_t j32;


 /**************************************************************
  * Numerical
  **************************************************************/  
  
  /*
  void DisplayDecimal8(uint16_t x, uint16_t y, uint8_t value);
  void DisplayDecimal16(uint16_t x, uint16_t y, uint16_t value);
  void DisplayDecimal32(uint16_t x, uint16_t y, uint32_t value);
  void DisplayDecimalSigned8(uint16_t x, uint16_t y, uint8_t value);
  void DisplayDecimalSigned16(uint16_t x, uint16_t y, uint16_t value);
  void DisplayDecimalSigned32(uint16_t x, uint16_t y, uint32_t value);
  void DisplayHex8(uint16_t x, uint16_t y, uint8_t value);
  void DisplayHex16(uint16_t x, uint16_t y, uint16_t value);
  void DisplayHex32(uint16_t x, uint16_t y, uint32_t value);
  void DisplayHex64(uint16_t x, uint16_t y, uint64_t value);
  void DisplayBinary8(uint16_t x, uint16_t y, uint8_t value);
  void DisplayBinary16(uint16_t x, uint16_t y, uint16_t value);
  */


  TouchPanel_SetConfig(0b00000111); // Enable Touchpanel Events


  // *****************************************************
  // Header
  // *****************************************************
  SetBrushColor(255, 255, 255);
  FillScreen_BrushColor();
  SetPenColor(255, 255, 255);
  SetBrushColor(80, 80, 200);
  DrawRect_BrushColorFill(2, 2, 237, 16);
  DisplayText_F(5, 5, PSTR("Numerical Instructions"));
  SetPenColor(0, 0, 0);
  SetBrushColor(255, 255, 255);

  if (0 == Wait_ms(2000)) return;


  //#define NCONF_NoPlus     (1<<0)   Bit Mask display no plus (DisplayDecimalSigned)
  //#define NCONF_NoZero     (1<<1)   Bit Mask display no leading zero (DisplayDecimal, DisplayDecimalSigned)
  //#define NCONF_LeftAdjust (1<<2)   Bit Mask display left adjust (DisplayDecimal, DisplayDecimalSigned)

  config = 0;  // right adjust, with zero, unsigned
  NumericalConfig(config);


  // *****************************************************
  // Titles
  // *****************************************************
  SetPenColor(0, 0, 220);
  DisplayText_F(5, 20, PSTR("Decimal 8/16/32bit:"));
  DisplayText_F(5, 70, PSTR("Decimal signed 8/16/32bit:"));
  DisplayText_F(5, 120, PSTR("Hexadecimal 8/16/32/64bit:"));
  DisplayText_F(5, 180, PSTR("Binary 8/16bit:"));
  SetPenColor(0, 0, 0);
  	

  i8=0;
  i16=0;
  i32=0;
  j8=-128;
  j16=-2000;
  j32=-2500;

  for (i=0; i<5000; i++)
  {

    // decimal unsigned 8/16/32 bit
    DisplayDecimal8(50, 30, i8);
    DisplayDecimal16(50, 40, i16);
    DisplayDecimal32(50, 50, i32);
  

    // decimal signed 8/16/32 bit
    DisplayDecimalSigned8(50, 80, j8);
    DisplayDecimalSigned16(50, 90, j16);
    DisplayDecimalSigned32(50, 100, j32);


    // hex 8/16/32/64 bit
    DisplayHex8(50, 130, i8);
    DisplayHex16(50, 140, i16);
    DisplayHex32(50, 150, i32);
    DisplayHex64(50, 160, (uint64_t)i32<<4);
 

    // binary 8/16 bit
    DisplayBinary8(50, 190, i8);
    DisplayBinary16(50, 200, i16);

    i8++;
	i16++;
	i32++;
	j8++;
	j16++;
	j32++;


    if (TOUCHPANEL_EVENT)
    {
      data = TouchPanel_ReadEvent();
	  if (data & TOUCH_EVENT_DOWN)
	  {
	    config = config << 1;
	    config |= 1;
		if (config > (NCONF_NoPlus | NCONF_NoZero | NCONF_LeftAdjust))
		{
		  NumericalConfig(0);		  
		  return;
        }

		NumericalConfig(config);
	    SetPenColor(0, 0, 220);
	    DisplayText_F(5, 240, PSTR("Configuration:"));	 
	    SetPenColor(80, 20, 0);
		if (config & NCONF_NoPlus) DisplayText_F(5, 250, PSTR("no plus"));	  
        if (config & NCONF_NoZero) DisplayText_F(5, 260, PSTR("no leading zeros"));
        if (config & NCONF_LeftAdjust) DisplayText_F(5, 270, PSTR("left adjust"));
        SetPenColor(0, 0, 0);

	  }
    }

  }


}


void Demo_Graphics(void)
{

  uint16_t x, y;
  uint8_t r, g, b;

 /**************************************************************
  * Graphics
  **************************************************************/
  
  /*
  void MoveTo(uint16_t x, uint16_t y);
  void LineTo_PenColor(uint16_t x, uint16_t y);
  void LineTo_BrushColor(uint16_t x, uint16_t y);
  void LineTo_RGBColor(uint16_t x, uint16_t y, uint8_t r, uint8_t g, uint8_t b);
  void DrawPixel_PenColor(uint16_t x, uint16_t y);
  void DrawPixel_BrushColor(uint16_t x, uint16_t y);
  void DrawPixel_RGBColor(uint16_t x, uint16_t y, uint8_t r, uint8_t g, uint8_t b);
  void DrawLine_PenColor(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
  void DrawLine_BrushColor(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
  void DrawLine_RGBColor(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2, uint8_t r, uint8_t g, uint8_t b);
  void DrawRect_PenColor(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
  void DrawRect_PenColorFill(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
  void DrawRect_BrushColor(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
  void DrawRect_BrushColorFill(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2);
  void DrawRect_RGBColor(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2, uint8_t r, uint8_t g, uint8_t b);
  void DrawRect_RGBColorFill(uint16_t x1, uint16_t y1, uint16_t x2, uint16_t y2, uint8_t r, uint8_t g, uint8_t b);
  void DrawCircle_PenColor(uint16_t x, uint16_t y, uint8_t radius);
  void DrawCircle_BrushColor(uint16_t x, uint16_t y, uint8_t radius);
  void DrawCircle_RGBColor(uint16_t x, uint16_t y, uint8_t radius, uint8_t r, uint8_t g, uint8_t b);
  void DrawImage_Begin(uint16_t x, uint16_t y, uint16_t width, uint16_t height);
  void DrawImage_WritePixel(uint8_t r, uint8_t g, uint8_t b);
  void DrawImage_Stop(void);

  */


  // *****************************************************
  // Header
  // *****************************************************
  FillScreen_BrushColor();
  SetPenColor(255, 255, 255);
  SetBrushColor(80, 80, 200);
  DrawRect_BrushColorFill(2, 2, 237, 16);
  DisplayText_F(5, 5, PSTR("Graphic Instructions"));
 // SetPenColor(0, 0, 0);
 // SetBrushColor(255, 255, 255);

  SetPenColor(255, 255, 255);
  SetBrushColor(0, 0, 0);


  if (0 == Wait_ms(3000)) return;

  while (1)
  {
    // *****************************************************
	// MoveTo, LineTo
	// *****************************************************
    DrawRect_BrushColorFill(0, 0, 239, 319);  // Clear
	DisplayText_F(5, 5, PSTR("MoveTo, LineTo ..."));
	
	x = 10;
	y = 30;
	MoveTo(x, y);
	do
	{
      x += 220;
	  LineTo_PenColor(x, y);
	  y += 10;
	  LineTo_PenColor(x, y);
      x -= 220;
	  LineTo_PenColor(x, y);
	  y += 10;
	  LineTo_PenColor(x, y);
    } while (y<300);


    if (0 == Wait_ms(1000)) return;

	x = 10;
	y = 30;
	MoveTo(x, y);
	do
	{
      x += 220;
	  LineTo_RGBColor(x, y, 255, 0, 0);
	  y += 10;
	  LineTo_RGBColor(x, y, 0, 255, 0);
      x -= 220;
	  LineTo_RGBColor(x, y, 0, 0, 255);
	  y += 10;
	  LineTo_RGBColor(x, y, 40, 80, 80);
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x = 10;
	y = 30;
	MoveTo(x, y);
	do
	{
      x += 220;
	  LineTo_BrushColor(x, y);
	  y += 10;
	  LineTo_BrushColor(x, y);
      x -= 220;
	  LineTo_BrushColor(x, y);
	  y += 10;
	  LineTo_BrushColor(x, y);
    } while (y<300);

    if (0 == Wait_ms(1000)) return;


    // *****************************************************
    // DrawPixel
	// *****************************************************

    DrawRect_BrushColorFill(0, 0, 239, 319);  // Clear
	DisplayText_F(5, 5, PSTR("DrawPixel ..."));

	for (x=50; x<200; x+=5)
	  for (y=20; y<310; y+=10)
	    DrawPixel_PenColor(x, y);

    if (0 == Wait_ms(1000)) return;

    for (x=50; x<200; x+=5)
	  for (y=20; y<310; y+=10)
        DrawPixel_RGBColor(x, y, x, 0, 255-x);

    if (0 == Wait_ms(1000)) return;

    for (x=50; x<200; x+=5)
	  for (y=20; y<310; y+=10)
        DrawPixel_BrushColor(x, y);

    if (0 == Wait_ms(1000)) return;


    // *****************************************************
    // DrawLine
	// *****************************************************

    DrawRect_BrushColorFill(0, 0, 239, 319);  // Clear
	DisplayText_F(5, 5, PSTR("DrawLine ..."));
    
	x=5;
	y=20;
	do
	{
	  DrawLine_PenColor(x, y, 230, 310);
      x += 5;
	  y += 10;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

 	x=5;
	y=20;
	do
	{
	  DrawLine_RGBColor(x, y, 230, 310, 255-x, 0, x);
      x += 5;
	  y += 10;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

 	x=5;
	y=20;
	do
	{
	  DrawLine_BrushColor(x, y, 230, 310);
      x += 5;
	  y += 10;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;


    // *****************************************************
    // DrawRect
	// *****************************************************

    DrawRect_BrushColorFill(0, 0, 239, 319);  // Clear
	DisplayText_F(5, 5, PSTR("DrawRect ..."));

	x=5;
	y=20;
	do
	{
	  DrawRect_PenColor(x, y, 230, 310);
      x += 5;
	  y += 10;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x=5;
	y=20;
	do
	{
	  DrawRect_RGBColor(x, y, 230, 310, 255-x, 0, x);
      x += 5;
	  y += 10;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x=5;
	y=20;
	do
	{
	  DrawRect_BrushColor(x, y, 230, 310);
      x += 5;
	  y += 10;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x=5;
	y=20;
	do
	{
	  DrawRect_PenColorFill(x, y, x+20, y+20);
      x += 14;
	  y += 22;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x=5;
	y=20;
	do
	{
	  DrawRect_RGBColorFill(x, y, x+20, y+20, 255-x, 0, x);
      x += 14;
	  y += 22;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x=5+25;
	y=20;
	do
	{
	  DrawRect_RGBColorFill(x, y, x+20, y+20, 0, 255-x, 0);
      x += 14;
	  y += 22;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;

	x=5+25+25;
	y=20;
	do
	{
	  DrawRect_RGBColorFill(x, y, x+20, y+20, 0, 0, 255-x);
      x += 14;
	  y += 22;
    } while (y<300);

    if (0 == Wait_ms(1000)) return;


    DrawRect_BrushColorFill(0, 18, 239, 319);  // Clear

    r = 0;
	g = 0;
	b = 255;
    for (x=5; x<230; x+=10)
	{
      for (y=20; y<310; y+=10)
	  {
        b--;
		r++;
        DrawRect_RGBColorFill(x, y, x+8, y+8, r, g, b);

      }
    }
    if (0 == Wait_ms(2500)) return;

    r = 0;
	g = 255;
	b = 0;
    for (x=5; x<230; x+=10)
	{
      for (y=20; y<310; y+=10)
	  {
		b++;
		g--;
        DrawRect_RGBColorFill(x, y, x+8, y+8, r, g, b);

      }
    }
    if (0 == Wait_ms(2500)) return;

    r = 0;
	g = 0;
	b = 0;
    for (x=5; x<230; x+=10)
	{
      for (y=20; y<310; y+=10)
	  {
		r++;
		g++;
        DrawRect_RGBColorFill(x, y, x+8, y+8, r, g, b);

      }
    }
    if (0 == Wait_ms(2500)) return;



    // *****************************************************
    // DrawCircle
	// *****************************************************

    DrawRect_BrushColorFill(0, 0, 239, 319);  // Clear
	DisplayText_F(5, 5, PSTR("DrawCircle ..."));


	for (x=10; x<100; x+=5)
      DrawCircle_PenColor(120, 160, x);

    if (0 == Wait_ms(1000)) return;

	for (x=10; x<100; x+=5)
      DrawCircle_RGBColor(120, 160, x, 255-x, 0, x);

    if (0 == Wait_ms(1000)) return;

	for (x=10; x<100; x+=5)
      DrawCircle_BrushColor(120, 160, x);

    if (0 == Wait_ms(1000)) return;

    for (r=0; r<250; r+=5)
	{
	  for (x=10; x<100; x+=5)
        DrawCircle_RGBColor(120, 160, x, r, r, 0);
    }




    // *****************************************************
    // DrawImage
    // This Demonstration shows how to send image data
	// *****************************************************

    DrawRect_BrushColorFill(0, 0, 239, 319);  // Clear
	DisplayText_F(5, 5, PSTR("DrawImage ..."));

    DrawImage_Begin(100, 100, 120, 180);

    for (y=0; y<300; y++)
	{
      for (x=0; x<120; x++)
	  {

        r=0;
        
        if (y <= 255)
		{
		  b = y;
          g = y;
        } else {
		  b = 255;
          g = 255;
		}

        if (x < 60)
		{
		  b=0; 
        } else {
		  g=0; 
		}

        if (y == 0) r = 255;
        if (y == 179) r = 255;
        if (x == 0) r = 255;
        if (x == 119) r = 255;

        DrawImage_WritePixel(r, g, b);

      }
	}

    DrawImage_Stop();
    if (0 == Wait_ms(1000)) return;

  }

}





// wait <ms> or return on TOUCH_EVENT_DOWN
uint8_t Wait_ms(uint16_t ms)
{
  uint8_t data;

  do
  {

    if (TOUCHPANEL_EVENT)
    {
      data = TouchPanel_ReadEvent();
	  if (data & TOUCH_EVENT_DOWN) return 0;
    }

    ms--;
	_delay_ms(1);
  
  } while (ms>0);

  return 0xFF;

}


 /*****************************************************
  CreateFileName

  Description: Helpfunction for creating a filename
  
  creates filename s="nnnnn.bmp" n=decimal index
  
  *****************************************************/
void CreateFileName(unsigned char *s, uint8_t index)
{
  
  uint8_t d;

  s[0] = '0';
  s[1] = '0';
  s[2] = '0';  // 100
  s[3] = '0';  //  10
  s[4] = '0';  //   1
  s[5] = '.';
  s[6] = 'b';
  s[7] = 'm';
  s[8] = 'p';
  s[9] = 0;


  for( d = '0'; index >= 100; index -= 100) d++;  // 100
  s[2] = d;

  for( d = '0'; index >= 10; index -= 10) d++;    // 10
  s[3] = d;

  s[4] = (uint8_t)index+'0';                     // 1

}
